svn commit: r1649778 - /tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java

2015-01-06 Thread markt
Author: markt
Date: Tue Jan  6 11:06:13 2015
New Revision: 1649778

URL: http://svn.apache.org/r1649778
Log:
Make final

Modified:
tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java

Modified: tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java?rev=1649778&r1=1649777&r2=1649778&view=diff
==
--- tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java Tue 
Jan  6 11:06:13 2015
@@ -93,7 +93,7 @@ public abstract class AbstractOutputBuff
 /**
  * Underlying output buffer.
  */
-protected OutputBuffer outputStreamOutputBuffer;
+protected final OutputBuffer outputStreamOutputBuffer;
 
 /**
  * Bytes written to client for the current request



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649780 - /tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java

2015-01-06 Thread markt
Author: markt
Date: Tue Jan  6 11:08:23 2015
New Revision: 1649780

URL: http://svn.apache.org/r1649780
Log:
Revert since it breaks a unit test

Modified:
tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java

Modified: tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java?rev=1649780&r1=1649779&r2=1649780&view=diff
==
--- tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java Tue 
Jan  6 11:08:23 2015
@@ -93,7 +93,7 @@ public abstract class AbstractOutputBuff
 /**
  * Underlying output buffer.
  */
-protected final OutputBuffer outputStreamOutputBuffer;
+protected OutputBuffer outputStreamOutputBuffer;
 
 /**
  * Bytes written to client for the current request



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649784 - /tomcat/jk/trunk/native/common/jk_status.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 11:30:05 2015
New Revision: 1649784

URL: http://svn.apache.org/r1649784
Log:
Reset maximum number of open backend connections
in status worker when statistics are reset.

This number is a new feature (BZ 56869).

Modified:
tomcat/jk/trunk/native/common/jk_status.c

Modified: tomcat/jk/trunk/native/common/jk_status.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_status.c?rev=1649784&r1=1649783&r2=1649784&view=diff
==
--- tomcat/jk/trunk/native/common/jk_status.c (original)
+++ tomcat/jk/trunk/native/common/jk_status.c Tue Jan  6 11:30:05 2015
@@ -4397,6 +4397,7 @@ static int reset_worker(jk_ws_service_t
 aw->s->transferred  = 0;
 aw->s->readed   = 0;
 aw->s->max_busy = 0;
+aw->s->max_connected= 0;
 aw->s->last_reset   = now;
 }
 JK_TRACE_EXIT(l);
@@ -4426,6 +4427,7 @@ static int reset_worker(jk_ws_service_t
 aw->s->transferred  = 0;
 aw->s->readed   = 0;
 aw->s->max_busy = 0;
+aw->s->max_connected= 0;
 aw->s->last_reset   = now;
 JK_TRACE_EXIT(l);
 return JK_TRUE;
@@ -4446,6 +4448,7 @@ static int reset_worker(jk_ws_service_t
 aw->s->transferred  = 0;
 aw->s->readed   = 0;
 aw->s->max_busy = 0;
+aw->s->max_connected= 0;
 aw->s->last_reset   = now;
 JK_TRACE_EXIT(l);
 return JK_TRUE;



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 56869] Add code to collect the maximum number of backend connections

2015-01-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=56869

--- Comment #3 from Rainer Jung  ---
I added a reset of the max connected count to the status worker in the general
statistics reset functions. See r1649784.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 57282] request process UML diagram seems outdated

2015-01-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=57282

--- Comment #10 from Stephen Chen  ---
Created attachment 32344
  --> https://issues.apache.org/bugzilla/attachment.cgi?id=32344&action=edit
request process(revised)

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 57282] request process UML diagram seems outdated

2015-01-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=57282

--- Comment #11 from Stephen Chen  ---
Created attachment 32345
  --> https://issues.apache.org/bugzilla/attachment.cgi?id=32345&action=edit
authenticate and realm

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 57282] request process UML diagram seems outdated

2015-01-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=57282

--- Comment #12 from Stephen Chen  ---
Hi Mark, please help to review the revised&advise request process and
Authenticator&Realm diagrams, thanks!

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649806 - in /tomcat/jk/trunk: native/common/jk_ajp_common.c xdocs/miscellaneous/changelog.xml

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 14:08:04 2015
New Revision: 1649806

URL: http://svn.apache.org/r1649806
Log:
Don't update last access time of worker
connections during optional checking of
idle connections using CPing.

Updating the time stamp breaks closing
idle connections.

Modified:
tomcat/jk/trunk/native/common/jk_ajp_common.c
tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml

Modified: tomcat/jk/trunk/native/common/jk_ajp_common.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_ajp_common.c?rev=1649806&r1=1649805&r2=1649806&view=diff
==
--- tomcat/jk/trunk/native/common/jk_ajp_common.c (original)
+++ tomcat/jk/trunk/native/common/jk_ajp_common.c Tue Jan  6 14:08:04 2015
@@ -3321,7 +3321,6 @@ int JK_METHOD ajp_maintain(jk_worker_t *
 
 if (pThis && pThis->worker_private) {
 ajp_worker_t *aw = pThis->worker_private;
-time_t now = mstarted;
 int i;
 long delta;
 unsigned int n = 0, k = 0, cnt = 0;
@@ -3409,7 +3408,7 @@ int JK_METHOD ajp_maintain(jk_worker_t *
  */
 if (IS_SLOT_AVAIL(aw->ep_cache[i]) &&
 IS_VALID_SOCKET(aw->ep_cache[i]->sd)) {
-int elapsed = (int)difftime(now, 
aw->ep_cache[i]->last_access);
+int elapsed = (int)difftime(mstarted, 
aw->ep_cache[i]->last_access);
 if (elapsed > aw->conn_ping_interval) {
 k++;
 /* handle cping/cpong.
@@ -3428,10 +3427,6 @@ int JK_METHOD ajp_maintain(jk_worker_t *
 aw->ep_cache[i]->sd = JK_INVALID_SOCKET;
 ajp_reset_endpoint(aw->ep_cache[i], l);
 }
-else {
-now = time(NULL);
-aw->ep_cache[i]->last_access = now;
-}
 }
 }
 }

Modified: tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml?rev=1649806&r1=1649805&r2=1649806&view=diff
==
--- tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml (original)
+++ tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml Tue Jan  6 14:08:04 2015
@@ -184,6 +184,11 @@
 Apache: Improve log handling during graceful or normal restart.
 (rjung)
   
+  
+Don't update last access time of worker connections during optional
+checking of idle connections using CPing. Updating the time stamp
+breaks closing idle connections. (rjung)
+  
 
   
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649807 - in /tomcat/jk/trunk/native/common: jk_ajp_common.c jk_uri_worker_map.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 14:10:27 2015
New Revision: 1649807

URL: http://svn.apache.org/r1649807
Log:
Join two separate debug log messages.

Modified:
tomcat/jk/trunk/native/common/jk_ajp_common.c
tomcat/jk/trunk/native/common/jk_uri_worker_map.c

Modified: tomcat/jk/trunk/native/common/jk_ajp_common.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_ajp_common.c?rev=1649807&r1=1649806&r2=1649807&view=diff
==
--- tomcat/jk/trunk/native/common/jk_ajp_common.c (original)
+++ tomcat/jk/trunk/native/common/jk_ajp_common.c Tue Jan  6 14:10:27 2015
@@ -3443,15 +3443,10 @@ int JK_METHOD ajp_maintain(jk_worker_t *
 }
 }
 free(m_sock);
-if (n && JK_IS_DEBUG_LEVEL(l))
+if ((k + n) && JK_IS_DEBUG_LEVEL(l))
 jk_log(l, JK_LOG_DEBUG,
-   "(%s) recycled %u sockets in %d seconds from %u pool slots",
-   aw->name, n, (int)(difftime(time(NULL), mstarted)),
-   aw->ep_cache_sz);
-if (k && JK_IS_DEBUG_LEVEL(l))
-jk_log(l, JK_LOG_DEBUG,
-   "(%s) pinged %u sockets in %d seconds from %u pool slots",
-   aw->name, k, (int)(difftime(time(NULL), mstarted)),
+   "(%s) pinged %u and recycled %u sockets in %d seconds from 
%u pool slots",
+   aw->name, k, n, (int)(difftime(time(NULL), mstarted)),
aw->ep_cache_sz);
 JK_TRACE_EXIT(l);
 return JK_TRUE;

Modified: tomcat/jk/trunk/native/common/jk_uri_worker_map.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_uri_worker_map.c?rev=1649807&r1=1649806&r2=1649807&view=diff
==
--- tomcat/jk/trunk/native/common/jk_uri_worker_map.c (original)
+++ tomcat/jk/trunk/native/common/jk_uri_worker_map.c Tue Jan  6 14:10:27 2015
@@ -1074,6 +1074,8 @@ const char *map_uri_to_worker_ext(jk_uri
 int reject_unsafe;
 int collapse_slashes;
 int rv = -1;
+size_t uri_len;
+size_t remain;
 char  url[JK_MAX_URI_LEN+1];
 
 JK_TRACE_ENTER(l);
@@ -1142,11 +1144,13 @@ const char *map_uri_to_worker_ext(jk_uri
 /* Make the copy of the provided uri and strip
  * everything after the first ';' char.
  */
-for (i = 0; i < strlen(uri); i++) {
-if (i == JK_MAX_URI_LEN) {
+uri_len = strlen(uri);
+remain = JK_MAX_URI_LEN - vhost_len;
+for (i = 0; i < uri_len; i++) {
+if (i == remain) {
 jk_log(l, JK_LOG_WARNING,
"URI %s is invalid. URI must be smaller than %d chars",
-   uri, JK_MAX_URI_LEN);
+   uri, remain);
 JK_TRACE_EXIT(l);
 return NULL;
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649828 - /tomcat/jk/trunk/native/common/jk_uri_worker_map.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 15:21:07 2015
New Revision: 1649828

URL: http://svn.apache.org/r1649828
Log:
Revert unintentional commit part of r1649807.

Modified:
tomcat/jk/trunk/native/common/jk_uri_worker_map.c

Modified: tomcat/jk/trunk/native/common/jk_uri_worker_map.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_uri_worker_map.c?rev=1649828&r1=1649827&r2=1649828&view=diff
==
--- tomcat/jk/trunk/native/common/jk_uri_worker_map.c (original)
+++ tomcat/jk/trunk/native/common/jk_uri_worker_map.c Tue Jan  6 15:21:07 2015
@@ -1074,8 +1074,6 @@ const char *map_uri_to_worker_ext(jk_uri
 int reject_unsafe;
 int collapse_slashes;
 int rv = -1;
-size_t uri_len;
-size_t remain;
 char  url[JK_MAX_URI_LEN+1];
 
 JK_TRACE_ENTER(l);
@@ -1144,13 +1142,11 @@ const char *map_uri_to_worker_ext(jk_uri
 /* Make the copy of the provided uri and strip
  * everything after the first ';' char.
  */
-uri_len = strlen(uri);
-remain = JK_MAX_URI_LEN - vhost_len;
-for (i = 0; i < uri_len; i++) {
-if (i == remain) {
+for (i = 0; i < strlen(uri); i++) {
+if (i == JK_MAX_URI_LEN) {
 jk_log(l, JK_LOG_WARNING,
"URI %s is invalid. URI must be smaller than %d chars",
-   uri, remain);
+   uri, JK_MAX_URI_LEN);
 JK_TRACE_EXIT(l);
 return NULL;
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649835 - in /tomcat/jk/trunk: native/common/jk_connect.c xdocs/miscellaneous/changelog.xml

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 15:35:49 2015
New Revision: 1649835

URL: http://svn.apache.org/r1649835
Log:
Adjust linger parameters used during connection
shutdown.

Modified:
tomcat/jk/trunk/native/common/jk_connect.c
tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml

Modified: tomcat/jk/trunk/native/common/jk_connect.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_connect.c?rev=1649835&r1=1649834&r2=1649835&view=diff
==
--- tomcat/jk/trunk/native/common/jk_connect.c (original)
+++ tomcat/jk/trunk/native/common/jk_connect.c Tue Jan  6 15:35:49 2015
@@ -831,8 +831,18 @@ int jk_close_socket(jk_sock_t sd, jk_log
 #ifndef MAX_SECS_TO_LINGER
 #define MAX_SECS_TO_LINGER 2
 #endif
-#define MS_TO_LINGER  500
-#define MS_TO_LINGER_LAST 2
+
+#ifndef MS_TO_LINGER
+#define MS_TO_LINGER  100
+#endif
+
+#ifndef MS_TO_LINGER_LAST
+#define MS_TO_LINGER_LAST 20
+#endif
+
+#ifndef MAX_READ_RETRY
+#define MAX_READ_RETRY 10
+#endif
 
 #ifndef MAX_LINGER_BYTES
 #define MAX_LINGER_BYTES 32768
@@ -908,7 +918,9 @@ int jk_shutdown_socket(jk_sock_t sd, jk_
 /* Do a restartable read on the socket
  * draining out all the data currently in the socket buffer.
  */
+int num = 0;
 do {
+num++;
 #if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
 rc = recv(sd, &dummy[0], sizeof(dummy), 0);
 if (JK_IS_SOCKET_ERROR(rc))
@@ -918,7 +930,7 @@ int jk_shutdown_socket(jk_sock_t sd, jk_
 #endif
 if (rc > 0)
 rp += rc;
-} while (JK_IS_SOCKET_ERROR(rc) && (errno == EINTR || errno == 
EAGAIN));
+} while (JK_IS_SOCKET_ERROR(rc) && (errno == EINTR || errno == 
EAGAIN) && num < MAX_READ_RETRY);
 
 if (rc < 0) {
 /* Read failed.

Modified: tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml?rev=1649835&r1=1649834&r2=1649835&view=diff
==
--- tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml (original)
+++ tomcat/jk/trunk/xdocs/miscellaneous/changelog.xml Tue Jan  6 15:35:49 2015
@@ -189,6 +189,9 @@
 checking of idle connections using CPing. Updating the time stamp
 breaks closing idle connections. (rjung)
   
+  
+Adjust linger parameters used during connection shutdown. (rjung)
+  
 
   
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GUMP@vmgump]: Project tomcat-trunk-test-apr (in module tomcat-trunk) failed

2015-01-06 Thread Bill Barker
To whom it may engage...

This is an automated request, but not an unsolicited one. For 
more information please visit http://gump.apache.org/nagged.html, 
and/or contact the folk at gene...@gump.apache.org.

Project tomcat-trunk-test-apr has an issue affecting its community integration.
This issue affects 1 projects.
The current state of this project is 'Failed', with reason 'Build Failed'.
For reference only, the following projects are affected by this:
- tomcat-trunk-test-apr :  Tomcat 9.x, a web server implementing the Java 
Servlet 4.0,
...


Full details are available at:

http://vmgump.apache.org/gump/public/tomcat-trunk/tomcat-trunk-test-apr/index.html

That said, some information snippets are provided here.

The following annotations (debug/informational/warning/error messages) were 
provided:
 -DEBUG- Dependency on commons-daemon exists, no need to add for property 
commons-daemon.native.src.tgz.
 -DEBUG- Dependency on commons-daemon exists, no need to add for property 
tomcat-native.tar.gz.
 -INFO- Failed with reason build failed
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/logs-APR
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/test-tmp-APR/logs



The following work was performed:
http://vmgump.apache.org/gump/public/tomcat-trunk/tomcat-trunk-test-apr/gump_work/build_tomcat-trunk_tomcat-trunk-test-apr.html
Work Name: build_tomcat-trunk_tomcat-trunk-test-apr (Type: Build)
Work ended in a state of : Failed
Elapsed: 25 mins 6 secs
Command Line: /usr/lib/jvm/java-8-oracle/bin/java -Djava.awt.headless=true 
-Dbuild.sysclasspath=only org.apache.tools.ant.Main 
-Dgump.merge=/srv/gump/public/gump/work/merge.xml 
-Djunit.jar=/srv/gump/public/workspace/junit/target/junit-4.13-SNAPSHOT.jar 
-Dobjenesis.jar=/srv/gump/public/workspace/objenesis/main/target/objenesis-2.2-SNAPSHOT.jar
 -Dtest.reports=output/logs-APR 
-Dtomcat-native.tar.gz=/srv/gump/public/workspace/apache-commons/daemon/dist/bin/commons-daemon-20150106-native-src.tar.gz
 -Dexamples.sources.skip=true 
-Djdt.jar=/srv/gump/packages/eclipse/plugins/R-4.4-201406061215/ecj-4.4.jar 
-Dtest.apr.loc=/srv/gump/public/workspace/tomcat-native/dest-20150106/lib 
-Dcommons-daemon.jar=/srv/gump/public/workspace/apache-commons/daemon/dist/commons-daemon-20150106.jar
 
-Dcommons-daemon.native.src.tgz=/srv/gump/public/workspace/apache-commons/daemon/dist/bin/commons-daemon-20150106-native-src.tar.gz
 -Dtest.temp=output/test-tmp-APR -Dtest.accesslog=true -Dexecute.test.nio=false 
-Dtest
 .openssl.path=/srv/gump/public/workspace/openssl/dest-20150106/bin/openssl 
-Dexecute.test.apr=true -Dexecute.test.nio2=false 
-Deasymock.jar=/srv/gump/public/workspace/easymock/easymock/target/easymock-3.4-SNAPSHOT.jar
 
-Dhamcrest.jar=/srv/gump/public/workspace/hamcrest/build/hamcrest-all-20150106.jar
 -Dcglib.jar=/srv/gump/packages/cglib/cglib-nodep-2.2.jar test 
[Working Directory: /srv/gump/public/workspace/tomcat-trunk]
CLASSPATH: 
/usr/lib/jvm/java-8-oracle/lib/tools.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/webapps/examples/WEB-INF/classes:/srv/gump/public/workspace/tomcat-trunk/output/testclasses:/srv/gump/public/workspace/ant/dist/lib/ant.jar:/srv/gump/public/workspace/ant/dist/lib/ant-launcher.jar:/srv/gump/public/workspace/ant/dist/lib/ant-jmf.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit4.jar:/srv/gump/public/workspace/ant/dist/lib/ant-swing.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-resolver.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-xalan2.jar:/srv/gump/public/workspace/xml-commons/java/build/resolver.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/bootstrap.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/tomcat-juli.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/annotations-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/servlet-api.ja
 
r:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jsp-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/el-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/websocket-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ant.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-storeconfig.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-coyote.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper-el.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-tribes.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ha.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-jni.jar:/srv/gump/public/workspace/tomcat-trunk

svn commit: r1649848 - /tomcat/jk/trunk/native/common/jk_util.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 16:01:35 2015
New Revision: 1649848

URL: http://svn.apache.org/r1649848
Log:
Fix compiler error (declare at start of block).

Modified:
tomcat/jk/trunk/native/common/jk_util.c

Modified: tomcat/jk/trunk/native/common/jk_util.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_util.c?rev=1649848&r1=1649847&r2=1649848&view=diff
==
--- tomcat/jk/trunk/native/common/jk_util.c (original)
+++ tomcat/jk/trunk/native/common/jk_util.c Tue Jan  6 16:01:35 2015
@@ -1402,15 +1402,16 @@ int jk_get_worker_fail_on_status(jk_map_
  int **list, unsigned int *list_size)
 {
 char buf[PARAM_BUFFER_SIZE];
+int *ar;
 
 if (!m || !wname || !list || !list_size) {
 return 0;
 }
 MAKE_WORKER_PARAM(STATUS_FAIL_OF_WORKER);
-int *ar = jk_map_get_int_list(m,
-  buf,
-  list_size,
-  NULL);
+ar = jk_map_get_int_list(m,
+ buf,
+ list_size,
+ NULL);
 if (ar) {
 *list = ar;
 return JK_TRUE;



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649849 - /tomcat/jk/trunk/native/common/jk_uri_worker_map.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 16:06:08 2015
New Revision: 1649849

URL: http://svn.apache.org/r1649849
Log:
Fix compiler error (declare at start of block).

Modified:
tomcat/jk/trunk/native/common/jk_uri_worker_map.c

Modified: tomcat/jk/trunk/native/common/jk_uri_worker_map.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/common/jk_uri_worker_map.c?rev=1649849&r1=1649848&r2=1649849&view=diff
==
--- tomcat/jk/trunk/native/common/jk_uri_worker_map.c (original)
+++ tomcat/jk/trunk/native/common/jk_uri_worker_map.c Tue Jan  6 16:06:08 2015
@@ -1186,6 +1186,7 @@ const char *map_uri_to_worker_ext(jk_uri
 
 /* In case we found a match, check for the unmounts. */
 if (rv >= 0 && IND_THIS(uw_map->nosize)) {
+int rc;
 if (collapse_slashes == JK_COLLAPSE_UNMOUNT) {
 /* Remove multiple slashes when looking for
  * unmount to prevent trivial unmount bypass attack.
@@ -1194,7 +1195,7 @@ const char *map_uri_to_worker_ext(jk_uri
 jk_no2slash(url);
 }
 /* Again first including vhost. */
-int rc = is_nomatch(uw_map, url, rv, l);
+rc = is_nomatch(uw_map, url, rv, l);
 /* If no unmount was found, try without vhost. */
 if (!rc && vhost_len)
 rc = is_nomatch(uw_map, &url[vhost_len], rv, l);



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649859 - /tomcat/jk/trunk/native/iis/jk_isapi_plugin.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 16:16:48 2015
New Revision: 1649859

URL: http://svn.apache.org/r1649859
Log:
Fix compiler error (declare at start of block).

Modified:
tomcat/jk/trunk/native/iis/jk_isapi_plugin.c

Modified: tomcat/jk/trunk/native/iis/jk_isapi_plugin.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/iis/jk_isapi_plugin.c?rev=1649859&r1=1649858&r2=1649859&view=diff
==
--- tomcat/jk/trunk/native/iis/jk_isapi_plugin.c (original)
+++ tomcat/jk/trunk/native/iis/jk_isapi_plugin.c Tue Jan  6 16:16:48 2015
@@ -3853,6 +3853,7 @@ static char *path_merge(const char *root
 rsz = strlen(root);
 /* Normalize path */
 if ((rel = relative_path(merge, &remain))) {
+size_t bl;
 if (remain > 0) {
 char *skip = root + rsz - 1;
 char *spr;
@@ -3877,7 +3878,7 @@ static char *path_merge(const char *root
 /* one additional byte for trailing '\0',
  * one additional byte for eventual path
  * separator between root and merge */
-size_t bl = strlen(root) + sz + 2;
+bl = strlen(root) + sz + 2;
 out = malloc(bl);
 if (out == 0)
 return 0;



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1649861 - /tomcat/jk/trunk/native/iis/jk_isapi_plugin.c

2015-01-06 Thread rjung
Author: rjung
Date: Tue Jan  6 16:19:23 2015
New Revision: 1649861

URL: http://svn.apache.org/r1649861
Log:
Fix compiler error in new function.
Need to work on string copy.

Modified:
tomcat/jk/trunk/native/iis/jk_isapi_plugin.c

Modified: tomcat/jk/trunk/native/iis/jk_isapi_plugin.c
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/native/iis/jk_isapi_plugin.c?rev=1649861&r1=1649860&r2=1649861&view=diff
==
-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 57420] New: Wrong class names generated since URL_ENCODER in DirContextURLConnection is not thread safe

2015-01-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=57420

Bug ID: 57420
   Summary: Wrong class names generated since URL_ENCODER in
DirContextURLConnection is not thread safe
   Product: Tomcat 7
   Version: 7.0.55
  Hardware: PC
Status: NEW
  Severity: critical
  Priority: P2
 Component: Catalina
  Assignee: dev@tomcat.apache.org
  Reporter: matthias.kel...@ergon.ch

We've been debugging this for a long time. Sometimes when tomcat starts up, it
will fail to deploy a webapp since it cannot find a certain class. That class
name is always complete garbage.

The error stack trace always is:
SEVERE: Unable to process resource element
[jndi:/localhost/testapp/WEB-INF/classes/ch/blabli/dNlewrP.lculgiansDisalog$3.class]
for annotations
java.io.FileNotFoundException:
jndi:/localhost/testapp/WEB-INF/classes/ch/blabli/dNlewrP.lculgiansDisalog$3.class
at
org.apache.naming.resources.DirContextURLConnection.getInputStream(DirContextURLConnection.java:389)

>From time to time we see, that the referenced class name is actually a mix of
the real class name and one or more other classes that exist in the vicinity of
that class.

Finally I was able to catch this exception with the debugger.
What I see is that the problem stems from
rg.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986):
- dcUrlConn (DirContextURLConnection) contains the correct entries of the WAR
file
- Enumeration dirs = dcUrlConn.list()  however does not. Calling list()
again from the debugger yields the correct results.

Here's the contents of that dirs variable:

[lCsosn, oCrAopnpfliigcEadtiitoonr$AEpdpiltiocraMtoidoen.$c2l.acslsass, ,
tCioonnfi$gu4r.aticolnaLsosad, liconaftgiuroatni$o5n.LocadlLaisstsen,
cCaotnifiognur$a6.clastsi, lCaonsfsig, s, cluaiss,
CwoindgfetisegtEditorApplication$9.class,
ConfigEditorApplication$ApplicationConfigLoadListener.class,
ConfigEditorApplication$ConfigEditorToParameterHandlerIntegration.class,
ConfigEditorApplication$EditorMode$1.class,
ConfigEditorApplication$EditorMode$2.class,
ConfigEditorApplication$EditorMode.class, ConfigEditorApplication.class,
ConfigLoader$1.class, ConfigLoader.class,
ConfigurationLoadListener$ConfigType.class,
ConfigurationLoadListener$ConfigurationLoadedEvent.class,
ConfigurationLoadListener$FailedToLoadConfigurationEvent.class,
ConfigurationLoadListener.class, command, data, field, rendering, session, ui,
util, widgetset]

walking into the list() command leads to collection.list("/") which in turn is
encoded using an URL_ENCODER (class UEncoder). This URL_ENCODER is *not* thread
safe and can result in exactly such garbage if used concurrently.

It is interesting to note that every single failure we had at this step was
always caused by classes in the WEB-INF/classes directory, never in JAR files
in WEB-INF/lib.

To me it appears that there are two different DirContextURLConnections with
rare concurrency issues when both use the same URL_ENCODER.

Here's the full stacktrace when the error occurs:
at
org.apache.naming.resources.DirContextURLConnection.getInputStream(DirContextURLConnection.java:389)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1994)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsJndi(ContextConfig.java:1986)
at
org.apache.catalina.startup.ContextConfig.processAnnotationsUrl(ContextConfig.java:1902)
at
org.apache.catalina.startup.ContextConfig.webConfig(ContextConfig.java:1298)
at
org.apache.catalina.startup.ContextConfig.configureStart(ContextConfig.java:876)
at
org.apache.catalina.startup.ContextConfig.lifecycleEvent(ContextConfig.java:374)
at
org.apache.catalina.util.LifecycleSupport.fireLifecycleEvent(LifecycleSupport.java:117)
at
org.apache.catalina.util.LifecycleBase.fireLifecycleEvent(LifecycleBase.java:90)
at
org.apache.catalina.core.StandardContext.startInternal(StandardContext.java:5378)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:150)
at
org.apache.catalina.core.ContainerBase.addChildInternal(ContainerBase.java:901)
at
org.apache.catalina.core.ContainerBase.addChild(ContainerBase.java:877)
at
org.apache.catalina.core.StandardHost.addChild(StandardHost.java:649)
at
org.apache.catalina.startup.HostConfig.deployWAR(HostCon

[GUMP@vmgump]: Project tomcat-trunk-test-apr (in module tomcat-trunk) failed

2015-01-06 Thread Bill Barker
To whom it may engage...

This is an automated request, but not an unsolicited one. For 
more information please visit http://gump.apache.org/nagged.html, 
and/or contact the folk at gene...@gump.apache.org.

Project tomcat-trunk-test-apr has an issue affecting its community integration.
This issue affects 1 projects.
The current state of this project is 'Failed', with reason 'Build Failed'.
For reference only, the following projects are affected by this:
- tomcat-trunk-test-apr :  Tomcat 9.x, a web server implementing the Java 
Servlet 4.0,
...


Full details are available at:

http://vmgump.apache.org/gump/public/tomcat-trunk/tomcat-trunk-test-apr/index.html

That said, some information snippets are provided here.

The following annotations (debug/informational/warning/error messages) were 
provided:
 -DEBUG- Dependency on commons-daemon exists, no need to add for property 
commons-daemon.native.src.tgz.
 -DEBUG- Dependency on commons-daemon exists, no need to add for property 
tomcat-native.tar.gz.
 -INFO- Failed with reason build failed
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/logs-APR
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/test-tmp-APR/logs



The following work was performed:
http://vmgump.apache.org/gump/public/tomcat-trunk/tomcat-trunk-test-apr/gump_work/build_tomcat-trunk_tomcat-trunk-test-apr.html
Work Name: build_tomcat-trunk_tomcat-trunk-test-apr (Type: Build)
Work ended in a state of : Failed
Elapsed: 24 mins 48 secs
Command Line: /usr/lib/jvm/java-8-oracle/bin/java -Djava.awt.headless=true 
-Dbuild.sysclasspath=only org.apache.tools.ant.Main 
-Dgump.merge=/srv/gump/public/gump/work/merge.xml 
-Djunit.jar=/srv/gump/public/workspace/junit/target/junit-4.13-SNAPSHOT.jar 
-Dobjenesis.jar=/srv/gump/public/workspace/objenesis/main/target/objenesis-2.2-SNAPSHOT.jar
 -Dtest.reports=output/logs-APR 
-Dtomcat-native.tar.gz=/srv/gump/public/workspace/apache-commons/daemon/dist/bin/commons-daemon-20150106-native-src.tar.gz
 -Dexamples.sources.skip=true 
-Djdt.jar=/srv/gump/packages/eclipse/plugins/R-4.4-201406061215/ecj-4.4.jar 
-Dtest.apr.loc=/srv/gump/public/workspace/tomcat-native/dest-20150106/lib 
-Dcommons-daemon.jar=/srv/gump/public/workspace/apache-commons/daemon/dist/commons-daemon-20150106.jar
 
-Dcommons-daemon.native.src.tgz=/srv/gump/public/workspace/apache-commons/daemon/dist/bin/commons-daemon-20150106-native-src.tar.gz
 -Dtest.temp=output/test-tmp-APR -Dtest.accesslog=true -Dexecute.test.nio=false 
-Dtest
 .openssl.path=/srv/gump/public/workspace/openssl/dest-20150106/bin/openssl 
-Dexecute.test.apr=true -Dexecute.test.nio2=false 
-Deasymock.jar=/srv/gump/public/workspace/easymock/easymock/target/easymock-3.4-SNAPSHOT.jar
 
-Dhamcrest.jar=/srv/gump/public/workspace/hamcrest/build/hamcrest-all-20150106.jar
 -Dcglib.jar=/srv/gump/packages/cglib/cglib-nodep-2.2.jar test 
[Working Directory: /srv/gump/public/workspace/tomcat-trunk]
CLASSPATH: 
/usr/lib/jvm/java-8-oracle/lib/tools.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/webapps/examples/WEB-INF/classes:/srv/gump/public/workspace/tomcat-trunk/output/testclasses:/srv/gump/public/workspace/ant/dist/lib/ant.jar:/srv/gump/public/workspace/ant/dist/lib/ant-launcher.jar:/srv/gump/public/workspace/ant/dist/lib/ant-jmf.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit4.jar:/srv/gump/public/workspace/ant/dist/lib/ant-swing.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-resolver.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-xalan2.jar:/srv/gump/public/workspace/xml-commons/java/build/resolver.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/bootstrap.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/tomcat-juli.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/annotations-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/servlet-api.ja
 
r:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jsp-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/el-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/websocket-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ant.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-storeconfig.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-coyote.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper-el.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-tribes.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ha.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-jni.jar:/srv/gump/public/workspace/tomcat-trunk

svn commit: r1649963 - /tomcat/jk/trunk/xdocs/reference/workers.xml

2015-01-06 Thread schultz
Author: schultz
Date: Tue Jan  6 22:41:41 2015
New Revision: 1649963

URL: http://svn.apache.org/r1649963
Log:
Fixed typo.

Modified:
tomcat/jk/trunk/xdocs/reference/workers.xml

Modified: tomcat/jk/trunk/xdocs/reference/workers.xml
URL: 
http://svn.apache.org/viewvc/tomcat/jk/trunk/xdocs/reference/workers.xml?rev=1649963&r1=1649962&r2=1649963&view=diff
==
--- tomcat/jk/trunk/xdocs/reference/workers.xml (original)
+++ tomcat/jk/trunk/xdocs/reference/workers.xml Tue Jan  6 22:41:41 2015
@@ -527,7 +527,7 @@ Specifies whether requests with SESSION
 should be rejected. If sticky_session_force is set to true
 and the worker that matches that SESSION ID is in error state, client will
 receive 500 (Server Error). If set to false failover on
-another worker will be issued with loosing client session. This directive is
+another worker will be issued with losing client session. This directive is
 used only when you set sticky_session=true.
 
 This feature has been added in jk 1.2.9.
@@ -982,7 +982,7 @@ Using this directive, a balanced worker
 can be configured as disabled or stopped. A disabled worker only gets
 requests, which belong to sessions for that worker. A stopped
 worker does not get any requests. Users of a stopped worker will
-loose their sessions, unless session replication via clustering is used.
+lose their sessions, unless session replication via clustering is used.
 
 Use d or D to disable and s or S to stop.
 If this directive is not present the deprecated directives



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Apache Tomcat 8.0.16

2015-01-06 Thread Christopher Schultz
Mark,

On 1/5/15 8:13 AM, Mark Thomas wrote:
> The proposed Apache Tomcat 8.0.16 release is now available for voting.
> 
> The main changes since 8.0.15 are:
> - Correct a regression in annotation scanning introduced in 8.0.15
> - The RemoteAddrValve and RemoteHostValve can now optionally include
>   the port when filtering along with a new option to trigger
>   authentication rather than denying access
> - Various edge cases fixes in WebSocket
> 
> There is also a large collection of bug fixes, new features and
> performance improvements. For full details, see the changelog:
> http://svn.us.apache.org/repos/asf/tomcat/tc8.0.x/trunk/webapps/docs/changelog.xml
> 
> It can be obtained from:
> https://dist.apache.org/repos/dist/dev/tomcat/tomcat-8/v8.0.16/
> The Maven staging repo is:
> https://repository.apache.org/content/repositories/orgapachetomcat-1028/
> The svn tag is:
> http://svn.apache.org/repos/asf/tomcat/tc8.0.x/tags/TOMCAT_8_0_16/
> 
> The proposed 8.0.16 release is:
> [ ] Broken - do not release
> [X] Stable - go ahead and release as 8.0.16

* Environment
*  Java: java version "1.7.0_67" Java(TM) SE Runtime Environment
(build 1.7.0_67-b01) Java HotSpot(TM) 64-Bit Server VM (build 24.65-b04,
mixed mode)
*  OS:   Linux 2.6.32-312-ec2 x86_64
*  cc:   cc (Debian 4.7.2-5) 4.7.2
*  make: GNU Make 3.81
*  OpenSSL:  OpenSSL 1.0.1e 11 Feb 2013
*  APR:  1.4.6
*
* Valid MD5 signature for apache-tomcat-8.0.16.zip
* Valid GPG signature for apache-tomcat-8.0.16.zip
* Valid MD5 signature for apache-tomcat-8.0.16.tar.gz
* Valid GPG signature for apache-tomcat-8.0.16.tar.gz
* Valid MD5 signature for apache-tomcat-8.0.16.exe
* Valid GPG signature for apache-tomcat-8.0.16.exe
* Valid MD5 signature for apache-tomcat-8.0.16-src.zip
* Valid GPG signature for apache-tomcat-8.0.16-src.zip
* Valid MD5 signature for apache-tomcat-8.0.16-src.tar.gz
* Valid GPG signature for apache-tomcat-8.0.16-src.tar.gz
*
* Binary Zip and tarball: Same
* Source Zip and tarball: Same
*
* tcnative builds cleanly (no warnings with stock build configuration)
* Tomcat builds cleanly
* Junit Tests: FAILED

The following unit tests failed, which are known to fail in my
environment due to lack of multicast support:

org.apache.catalina.session.TestStandardSession.APR.txt
org.apache.catalina.session.TestStandardSession.BIO.txt
org.apache.catalina.session.TestStandardSession.NIO2.txt
org.apache.catalina.session.TestStandardSession.NIO.txt
org.apache.catalina.tribes.group.interceptors.TestNonBlockingCoordinator.APR.txt
org.apache.catalina.tribes.group.interceptors.TestNonBlockingCoordinator.BIO.txt
org.apache.catalina.tribes.group.interceptors.TestNonBlockingCoordinator.NIO2.txt
org.apache.catalina.tribes.group.interceptors.TestNonBlockingCoordinator.NIO.txt
org.apache.catalina.tribes.group.interceptors.TestOrderInterceptor.APR.txt
org.apache.catalina.tribes.group.interceptors.TestOrderInterceptor.BIO.txt
org.apache.catalina.tribes.group.interceptors.TestOrderInterceptor.NIO2.txt
org.apache.catalina.tribes.group.interceptors.TestOrderInterceptor.NIO.txt
org.apache.catalina.tribes.group.interceptors.TestTcpFailureDetector.APR.txt
org.apache.catalina.tribes.group.interceptors.TestTcpFailureDetector.BIO.txt
org.apache.catalina.tribes.group.interceptors.TestTcpFailureDetector.NIO2.txt
org.apache.catalina.tribes.group.interceptors.TestTcpFailureDetector.NIO.txt
org.apache.catalina.tribes.group.TestGroupChannelMemberArrival.APR.txt
org.apache.catalina.tribes.group.TestGroupChannelMemberArrival.BIO.txt
org.apache.catalina.tribes.group.TestGroupChannelMemberArrival.NIO2.txt
org.apache.catalina.tribes.group.TestGroupChannelMemberArrival.NIO.txt
org.apache.catalina.tribes.group.TestGroupChannelSenderConnections.APR.txt
org.apache.catalina.tribes.group.TestGroupChannelSenderConnections.BIO.txt
org.apache.catalina.tribes.group.TestGroupChannelSenderConnections.NIO2.txt
org.apache.catalina.tribes.group.TestGroupChannelSenderConnections.NIO.txt
org.apache.catalina.tribes.group.TestGroupChannelStartStop.APR.txt
org.apache.catalina.tribes.group.TestGroupChannelStartStop.BIO.txt
org.apache.catalina.tribes.group.TestGroupChannelStartStop.NIO2.txt
org.apache.catalina.tribes.group.TestGroupChannelStartStop.NIO.txt

Works on our development web applications (pretty standard stuff; no
Websocket, etc.).

-chris



signature.asc
Description: OpenPGP digital signature


[mod_jk] Modify how common/config.h gets built

2015-01-06 Thread Christopher Schultz
All,

I give up. I can't seem to figure out exactly how common/config.h comes
into existence during the "configure" process.

When compiling on Mac OS X, I get the following irritating warning:

In file included from mod_jk.c:89:
In file included from ../common/jk_global.h:29:
../common/config.h:81:9: warning: 'PACKAGE_NAME' macro redefined
#define PACKAGE_NAME "mod_jk"
^
/usr/include/apache2/ap_config_auto.h:213:9: note: previous definition
is here
#define PACKAGE_NAME ""
^

There are 3 others like it for a few other #defines. I would like to
clean these up, but I can't just commit changes to common/config.h
because it's auto-generated.

Can anyone shed some light on where I can modify what gets dumped into
common/config.h? I see some stuff in config.status, but that in turn
gets generated by configure.

Any suggestions?

Thanks,
-chris



signature.asc
Description: OpenPGP digital signature


svn commit: r1649973 - /tomcat/trunk/test/org/apache/coyote/http11/upgrade/TestUpgrade.java

2015-01-06 Thread markt
Author: markt
Date: Tue Jan  6 23:33:16 2015
New Revision: 1649973

URL: http://svn.apache.org/r1649973
Log:
Correct method name

Modified:
tomcat/trunk/test/org/apache/coyote/http11/upgrade/TestUpgrade.java

Modified: tomcat/trunk/test/org/apache/coyote/http11/upgrade/TestUpgrade.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/coyote/http11/upgrade/TestUpgrade.java?rev=1649973&r1=1649972&r2=1649973&view=diff
==
--- tomcat/trunk/test/org/apache/coyote/http11/upgrade/TestUpgrade.java 
(original)
+++ tomcat/trunk/test/org/apache/coyote/http11/upgrade/TestUpgrade.java Tue Jan 
 6 23:33:16 2015
@@ -286,7 +286,7 @@ public class TestUpgrade extends TomcatB
 sos.write(buffer, 0, read);
 } else {
 throw new IOException("Unable to echo data. " +
-"canWrite() returned false");
+"isReady() returned false");
 }
 }
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [mod_jk] Modify how common/config.h gets built

2015-01-06 Thread Konstantin Kolinko
2015-01-07 2:25 GMT+03:00 Christopher Schultz :
> All,
>
> I give up. I can't seem to figure out exactly how common/config.h comes
> into existence during the "configure" process.

Hi!

I have never built mod_jk, but here are some thoughts

> When compiling on Mac OS X, I get the following irritating warning:
>
> In file included from mod_jk.c:89:
> In file included from ../common/jk_global.h:29:
> ../common/config.h:81:9: warning: 'PACKAGE_NAME' macro redefined
> #define PACKAGE_NAME "mod_jk"
> ^

1. I think that the PACKAGE_NAME define is generated by the following
macro in native/configure.ac:

dnl package and version.
dnl synchronization with common/jk_version.h ?
AC_INIT([mod_jk], [1.2.41])


> /usr/include/apache2/ap_config_auto.h:213:9: note: previous definition
> is here
> #define PACKAGE_NAME ""
> ^

2. From the path and file name, I think that the above header file
belongs to Apache HTTPD, not mod_jk.  It is no wonder that it has a
different PACKAGE_NAME.

> There are 3 others like it for a few other #defines. I would like to
> clean these up, but I can't just commit changes to common/config.h
> because it's auto-generated.
>
> Can anyone shed some light on where I can modify what gets dumped into
> common/config.h? I see some stuff in config.status, but that in turn
> gets generated by configure.
>
> Any suggestions?

Best regards,
Konstantin Kolinko

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Test mail Pls Ignore

2015-01-06 Thread My List



Re: [VOTE] Release Apache Tomcat 8.0.16

2015-01-06 Thread Violeta Georgieva
Hi,

2015-01-05 15:13 GMT+02:00 Mark Thomas :
>
> The proposed Apache Tomcat 8.0.16 release is now available for voting.
>
> The main changes since 8.0.15 are:
> - Correct a regression in annotation scanning introduced in 8.0.15
> - The RemoteAddrValve and RemoteHostValve can now optionally include
>   the port when filtering along with a new option to trigger
>   authentication rather than denying access
> - Various edge cases fixes in WebSocket
>
> There is also a large collection of bug fixes, new features and
> performance improvements. For full details, see the changelog:
>
http://svn.us.apache.org/repos/asf/tomcat/tc8.0.x/trunk/webapps/docs/changelog.xml
>
> It can be obtained from:
> https://dist.apache.org/repos/dist/dev/tomcat/tomcat-8/v8.0.16/
> The Maven staging repo is:
> https://repository.apache.org/content/repositories/orgapachetomcat-1028/
> The svn tag is:
> http://svn.apache.org/repos/asf/tomcat/tc8.0.x/tags/TOMCAT_8_0_16/
>
> The proposed 8.0.16 release is:
> [ ] Broken - do not release
> [ ] Stable - go ahead and release as 8.0.16
>

After revision 1643232
If there is a ServletRequestListener and the application sends an error
then ServletRequestListener.requestDestroyed is not invoked anymore.
I'm attaching a test case.

Regards,
Violeta

>
> -
> To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
> For additional commands, e-mail: dev-h...@tomcat.apache.org
>

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org
--- tomcat/jk/trunk/native/iis/jk_isapi_plugin.c (original)
+++ tomcat/jk/trunk/native/iis/jk_isapi_plugin.c Tue Jan  6 16:19:23 2015
@@ -3833,7 +3833,8 @@ static char *relative_path(char *path, i
 
 static char *path_merge(const char *root, const char *path)
 {
-char  merge[8192];
+char merge[8192];
+char dir[MAX_PATH];
 char *rel;
 char *out = 0;
 size_t sz;
@@ -3844,20 +3845,24 @@ static char *path_merge(const char *root
 SetLastError(ERROR_INVALID_PARAMETER );
 return 0;
 }
+if (FAILED(StringCbCopy(dir, MAX_PATH, root))) {
+SetLastError(ERROR_FILENAME_EXCED_RANGE);
+return 0;
+}
 if (FAILED(StringCbCopy(merge, 8190, path))) {
 /* TODO: Use dynamic buffer with larger size */
 SetLastError(ERROR_FILENAME_EXCED_RANGE);
 return 0;
 }
 sz = strlen(merge);
-rsz = strlen(root);
+rsz = strlen(dir);
 /* Normalize path */
 if ((rel = relative_path(merge, &remain))) {
 size_t bl;
 if (remain > 0) {
-char *skip = root + rsz - 1;
+char *skip = dir + rsz - 1;
 char *spr;
-char *start = skip_prefix(root, &spr);
+char *start = skip_prefix(dir, &spr);
 if (*skip == '/')
 skip--;
 while (remain > 0 && skip >= start) {
@@ -3877,13 +3882,13 @@ static char *path_merge(const char *root
 }
 /* one additional byte for trailing '\0',
  * one additional byte for eventual path
- * separator between root and merge */
-bl = strlen(root) + sz + 2;
+ * separator between dir and merge */
+bl = strlen(dir) + sz + 2;
 out = malloc(bl);
 if (out == 0)
 return 0;
-/* Prepend root */
-StringCbCopy(out, bl, root);
+/* Prepend dir */
+StringCbCopy(out, bl, dir);
 sz = strlen(out);
 BS2FSA(out);
 _INS_TRAILING_PATH_SEP(out, sz);



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 44454] busy count reported in mod_jk inflated, causes incorrect balancing

2015-01-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=44454

--- Comment #30 from Christopher Schultz  ---
Should we add a WARN-level log message if the user requests "busyness" and the
binary does not support atomic busyness-tracking?

I think that's a reasonable warning to issue. We could just emit that log on
startup... no need to spew logs repeatedly.
